@@ -9,7 +9,7 @@ def home():
     services = discover_devices.discover_chromecasts()
     chromecasts = []
 
-    for chromecast in services:
+    for chromecast in services or []:
         chromecasts.append({
             "ip": chromecast.host,
             "port": chromecast.port,
